searchData={"items":[{"type":"module","title":"Mistral","doc":"![GitHub CI](https://github.com/rodloboz/mistral/actions/workflows/all-checks-pass.yml/badge.svg)\n\n[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)\n\nClient for the Mistral AI API.\n\nThis library provides a simple and convenient way to integrate with Mistral's\nAPI, allowing you to use their powerful language models in your Elixir applications.","ref":"Mistral.html"},{"type":"module","title":"Installation - Mistral","doc":"Add `mistral` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:mistral, \"~> 0.4.0\"}\n  ]\nend\n```","ref":"Mistral.html#module-installation"},{"type":"module","title":"Configuration - Mistral","doc":"Set your Mistral API key in your config:\n\n```elixir\nconfig :mistral, :api_key, \"your_mistral_api_key\"\n```","ref":"Mistral.html#module-configuration"},{"type":"module","title":"Usage Examples - Mistral","doc":"","ref":"Mistral.html#module-usage-examples"},{"type":"module","title":"Chat Completion - Mistral","doc":"```elixir\n{:ok, client} = Mistral.init(\"your_api_key\")\n\n{:ok, response} = Mistral.chat(client,\n  model: \"mistral-small-latest\",\n  messages: [\n    %{role: \"user\", content: \"Write a haiku about elixir\"}\n  ]\n)\n```","ref":"Mistral.html#module-chat-completion"},{"type":"function","title":"Mistral.chat/2","doc":"Chat with a Mistral model. Send messages and get a completion from the model.","ref":"Mistral.html#chat/2"},{"type":"function","title":"Options - Mistral.chat/2","doc":"* `:model` (`t:String.t/0`) - Required. The model to use for generating the response.\n* `:messages` (list of `t:map/0`) - Required. List of messages in the conversation.\n* `:temperature` (`t:float/0`) - Controls randomness. Lower values are more deterministic (0.0 to 1.5).\n* `:top_p` (`t:float/0`) - Controls diversity via nucleus sampling. Considers only tokens with the top_p probability mass. The default value is `1.0`.\n* `:max_tokens` (`t:non_neg_integer/0`) - Maximum number of tokens to generate.\n* `:stream` - When true, returns a stream of partial response chunks. The default value is `false`.\n* `:random_seed` (`t:non_neg_integer/0`) - Seed for deterministic results.\n* `:tools` (list of `t:map/0`) - List of tools available to the model.\n* `:tool_choice` - Controls tool selection. Options: 'auto', 'any', 'none', or a specific tool.\n* `:presence_penalty` (`t:float/0`) - Penalizes repetition of tokens. Higher values reduce repetition. The default value is `0.0`.\n* `:frequency_penalty` (`t:float/0`) - Penalizes tokens based on their frequency. Higher values reduce repetition. The default value is `0.0`.\n* `:safe_prompt` (`t:boolean/0`) - Whether to inject a safety prompt before all conversations. The default value is `false`.\n* `:response_format` - *(optional)* Controls the output format. Use for JSON mode or structured output with schema validation.","ref":"Mistral.html#chat/2-options"},{"type":"function","title":"Message structure - Mistral.chat/2","doc":"Each message is a map with the following fields:\n\n* `:role` - Required. The role of the message, either `system`, `user`, `assistant` or `tool`.\n* `:content` - The content of the message.\n* `:tool_calls` - *(optional)* Tool calls from the assistant that the model wants to use.\n* `:tool_call_id` (`t:String.t/0`) - *(optional)* Required when `role` is 'tool'. ID of the tool call this message is responding to.","ref":"Mistral.html#chat/2-message-structure"},{"type":"function","title":"Tool structure - Mistral.chat/2","doc":"Each tool is a map with the following fields:\n\n* `:type` - Required. The type of tool. Currently only 'function' is supported.\n* `:function` (`t:map/0`) - Required. The function definition.\n  * `:name` (`t:String.t/0`) - Required. The name of the function to be called.\n  * `:description` (`t:String.t/0`) - *(optional)* A description of what the function does.\n  * `:parameters` - Required. The parameters the function accepts, described as a JSON Schema object.","ref":"Mistral.html#chat/2-tool-structure"},{"type":"function","title":"Examples - Mistral.chat/2","doc":"iex> Mistral.chat(client, [\n    ...>   model: \"mistral-small-latest\",\n    ...>   messages: [\n    ...>     %{role: \"user\", content: \"Write a haiku.\"}\n    ...>   ]\n    ...> ])\n    {:ok, %{\"choices\" => [%{\"message\" => %{\"content\" => \"Nature's whisper soft...\"}}], ...}}\n\n    # Stream the response\n    iex> {:ok, stream} = Mistral.chat(client, [\n    ...>   model: \"mistral-small-latest\",\n    ...>   messages: [%{role: \"user\", content: \"Write a haiku.\"}],\n    ...>   stream: true\n    ...> ])\n    iex> Enum.to_list(stream)\n    [%{\"choices\" => [%{\"delta\" => ...}]}, ...]","ref":"Mistral.html#chat/2-examples"},{"type":"function","title":"Tool Example - Mistral.chat/2","doc":"iex> Mistral.chat(client, [\n    ...>   model: \"mistral-large-latest\",\n    ...>   messages: [%{role: \"user\", content: \"What is the weather?\"}],\n    ...>   tools: [\n    ...>     %{\n    ...>       type: \"function\",\n    ...>       function: %{\n    ...>         name: \"get_weather\",\n    ...>         description: \"Fetches current weather\",\n    ...>         parameters: %{type: \"object\", properties: %{}}\n    ...>       }\n    ...>     }\n    ...>   ],\n    ...>   tool_choice: \"auto\"\n    ...> ])","ref":"Mistral.html#chat/2-tool-example"},{"type":"function","title":"Response Format Control - Mistral.chat/2","doc":"You can control the output format using the `response_format` parameter:\n\n    iex> # JSON mode - ensures response is valid JSON\n    iex> Mistral.chat(client, [\n    ...>   model: \"mistral-small-latest\",\n    ...>   messages: [%{role: \"user\", content: \"Generate user data in JSON format\"}],\n    ...>   response_format: %{type: \"json_object\"}\n    ...> ])\n\n    iex> # JSON Schema mode - validates response against schema\n    iex> user_schema = %{\n    ...>   type: \"object\",\n    ...>   title: \"UserProfile\",\n    ...>   properties: %{\n    ...>     name: %{type: \"string\", title: \"Name\"},\n    ...>     age: %{type: \"integer\", title: \"Age\", minimum: 0},\n    ...>     email: %{type: \"string\", title: \"Email\"}\n    ...>   },\n    ...>   required: [\"name\", \"age\"],\n    ...>   additionalProperties: false\n    ...> }\n    iex> Mistral.chat(client, [\n    ...>   model: \"mistral-small-latest\",\n    ...>   messages: [%{role: \"user\", content: \"Generate a user profile\"}],\n    ...>   response_format: %{\n    ...>     type: \"json_schema\",\n    ...>     json_schema: %{\n    ...>       name: \"user_profile\",\n    ...>       schema: user_schema,\n    ...>       strict: true\n    ...>     }\n    ...>   }\n    ...> ])","ref":"Mistral.html#chat/2-response-format-control"},{"type":"type","title":"Mistral.client/0","doc":"Client struct","ref":"Mistral.html#t:client/0"},{"type":"function","title":"Mistral.embed/2","doc":"Generate embeddings for the given input using a specified model.","ref":"Mistral.html#embed/2"},{"type":"function","title":"Options - Mistral.embed/2","doc":"* `:model` (`t:String.t/0`) - The model to use for generating embeddings. The default value is `\"mistral-embed\"`.\n* `:input` - Required. Text or list of texts to generate embeddings for.","ref":"Mistral.html#embed/2-options"},{"type":"function","title":"Examples - Mistral.embed/2","doc":"iex> Mistral.embed(client, input: \"Hello, world!\")\n    {:ok, %{\"data\" => [%{\"embedding\" => [...]}]}}\n\n    iex> Mistral.embed(client, input: [\"First text\", \"Second text\"])\n    {:ok, %{\"data\" => [%{\"embedding\" => [...]}, %{\"embedding\" => [...]}]}}","ref":"Mistral.html#embed/2-examples"},{"type":"function","title":"Mistral.get_file/2","doc":"Retrieves information about a specific file by its ID.","ref":"Mistral.html#get_file/2"},{"type":"function","title":"Parameters - Mistral.get_file/2","doc":"- `client`: A `Mistral.client()` struct.\n  - `file_id`: The ID of the file to retrieve.","ref":"Mistral.html#get_file/2-parameters"},{"type":"function","title":"Examples - Mistral.get_file/2","doc":"iex> Mistral.get_file(client, \"00edaf84-95b0-45db-8f83-f71138491f23\")\n    {:ok, %{\n      \"id\" => \"00edaf84-95b0-45db-8f83-f71138491f23\",\n      \"object\" => \"file\",\n      \"bytes\" => 3749788,\n      \"created_at\" => 1741023462,\n      \"filename\" => \"test_document.pdf\",\n      \"purpose\" => \"ocr\",\n      \"sample_type\" => \"ocr_input\",\n      \"source\" => \"upload\",\n      \"deleted\" => false\n    }}","ref":"Mistral.html#get_file/2-examples"},{"type":"function","title":"Mistral.get_file_url/3","doc":"Retrieves a signed URL for the specified file.","ref":"Mistral.html#get_file_url/3"},{"type":"function","title":"Parameters - Mistral.get_file_url/3","doc":"- `client`: A `Mistral.client()` struct.\n  - `file_id`: The ID of the file.\n  - `opts`: An optional keyword list for additional query parameters (e.g., `expiry`).","ref":"Mistral.html#get_file_url/3-parameters"},{"type":"function","title":"Examples - Mistral.get_file_url/3","doc":"iex> Mistral.get_file_url(client, \"00edaf84-95b0-45db-8f83-f71138491f23\")\n    {:ok, %{\"url\" => \"https://storage.googleapis.com/mistral-file-uploads/signed-url-example\"}}\n\n    iex> Mistral.get_file_url(client, \"00edaf84-95b0-45db-8f83-f71138491f23\", expiry: 48)\n    {:ok, %{\"url\" => \"https://storage.googleapis.com/mistral-file-uploads/signed-url-example\"}}","ref":"Mistral.html#get_file_url/3-examples"},{"type":"function","title":"Mistral.get_model/2","doc":"Retrieves information about a specific model by its ID.","ref":"Mistral.html#get_model/2"},{"type":"function","title":"Parameters - Mistral.get_model/2","doc":"- `client`: A `Mistral.client()` struct.\n  - `model_id`: The ID of the model to retrieve (e.g. \"mistral-small-latest\").","ref":"Mistral.html#get_model/2-parameters"},{"type":"function","title":"Examples - Mistral.get_model/2","doc":"iex> Mistral.get_model(client, \"mistral-small-latest\")\n    {:ok, %{\n      \"id\" => \"mistral-small-latest\",\n      \"object\" => \"model\",\n      \"created\" => 1711430400,\n      \"owned_by\" => \"mistralai\",\n      \"capabilities\" => %{\n        \"completion_chat\" => true,\n        \"function_calling\" => true,\n        \"vision\" => false\n      },\n      \"name\" => \"Mistral Small\"\n    }}","ref":"Mistral.html#get_model/2-examples"},{"type":"function","title":"Mistral.init/0","doc":"Creates a new Mistral API client using the API key set in your application's config.\n\n```elixir\nconfig :mistral, :api_key, \"your-api-key\"\n```\n\nIf given, a keyword list of options will be passed to `Req.new/1`.","ref":"Mistral.html#init/0"},{"type":"function","title":"Examples - Mistral.init/0","doc":"iex> client = Mistral.init()\n    %Mistral{}\n\n    iex> client = Mistral.init(headers: [{\"X-Custom-Header\", \"value\"}])\n    %Mistral{}","ref":"Mistral.html#init/0-examples"},{"type":"function","title":"Mistral.init/1","doc":"","ref":"Mistral.html#init/1"},{"type":"function","title":"Mistral.init/2","doc":"Creates a new Mistral API client with the given API key.\n\nOptionally, a keyword list of options can be passed through to `Req.new/1`.","ref":"Mistral.html#init/2"},{"type":"function","title":"Examples - Mistral.init/2","doc":"iex> client = Mistral.init(\"YOUR_API_KEY\")\n    %Mistral{}\n\n    iex> client = Mistral.init(\"YOUR_API_KEY\", receive_timeout: :infinity)\n    %Mistral{}","ref":"Mistral.html#init/2-examples"},{"type":"function","title":"Mistral.list_models/1","doc":"Lists all available models.","ref":"Mistral.html#list_models/1"},{"type":"function","title":"Examples - Mistral.list_models/1","doc":"iex> Mistral.list_models(client)\n    {:ok, %{\n      \"object\" => \"list\",\n      \"data\" => [\n        %{\n          \"id\" => \"mistral-small-latest\",\n          \"object\" => \"model\",\n          \"created\" => 1711430400,\n          \"owned_by\" => \"mistralai\",\n          \"capabilities\" => %{\n            \"completion_chat\" => true,\n            \"function_calling\" => true\n          }\n        }\n      ]\n    }}","ref":"Mistral.html#list_models/1-examples"},{"type":"function","title":"Mistral.ocr/2","doc":"Perform OCR on a document or image.","ref":"Mistral.html#ocr/2"},{"type":"function","title":"Options - Mistral.ocr/2","doc":"* `:model` - Required. Model to use for OCR processing.\n* `:id` (`t:String.t/0`) - Unique identifier for the OCR request.\n* `:document` - Required. Document object containing the URL or image URL.\n* `:pages` - List of page indices to process (starting from 0).\n* `:include_image_base64` - Include base64 images in the response.\n* `:image_limit` - Maximum number of images to extract.\n* `:image_min_size` - Minimum image dimensions to extract.\n* `:bbox_annotation_format` - *(optional)* Structured output for extracting information from each bounding box/image. Only json_schema type is valid.\n* `:document_annotation_format` - *(optional)* Structured output for extracting information from the entire document. Only json_schema type is valid.","ref":"Mistral.html#ocr/2-options"},{"type":"function","title":"Examples - Mistral.ocr/2","doc":"iex> Mistral.ocr(client, model: \"mistral-ocr-latest\", document: %{type: \"document_url\", document_url: \"https://example.com/sample.pdf\"})\n    {:ok, %{\"pages\" => [...]}}\n\n    iex> Mistral.ocr(client, model: \"mistral-ocr-latest\", document: %{type: \"image_url\", image_url: \"https://example.com/sample.png\"})\n    {:ok, %{\"pages\" => [...]}}","ref":"Mistral.html#ocr/2-examples"},{"type":"function","title":"Structured Output for OCR - Mistral.ocr/2","doc":"You can extract structured information from documents using annotation formats:\n\n    iex> # Extract structured data from bounding boxes\n    iex> bbox_schema = %{\n    ...>   type: \"object\",\n    ...>   title: \"BoundingBoxData\",\n    ...>   properties: %{\n    ...>     text: %{type: \"string\", title: \"Text\"},\n    ...>     confidence: %{type: \"number\", title: \"Confidence\", minimum: 0, maximum: 1}\n    ...>   },\n    ...>   additionalProperties: false\n    ...> }\n    iex> Mistral.ocr(client,\n    ...>   model: \"mistral-ocr-latest\",\n    ...>   document: %{type: \"document_url\", document_url: \"https://example.com/invoice.pdf\"},\n    ...>   bbox_annotation_format: %{\n    ...>     type: \"json_schema\",\n    ...>     json_schema: %{name: \"bbox_data\", schema: bbox_schema}\n    ...>   }\n    ...> )\n\n    iex> # Extract document-level structured information\n    iex> doc_schema = %{\n    ...>   type: \"object\",\n    ...>   title: \"DocumentInfo\",\n    ...>   properties: %{\n    ...>     title: %{type: \"string\", title: \"Title\"},\n    ...>     summary: %{type: \"string\", title: \"Summary\"},\n    ...>     total_pages: %{type: \"integer\", title: \"TotalPages\"}\n    ...>   },\n    ...>   additionalProperties: false\n    ...> }\n    iex> Mistral.ocr(client,\n    ...>   model: \"mistral-ocr-latest\",\n    ...>   document: %{type: \"document_url\", document_url: \"https://example.com/report.pdf\"},\n    ...>   document_annotation_format: %{\n    ...>     type: \"json_schema\",\n    ...>     json_schema: %{name: \"document_info\", schema: doc_schema}\n    ...>   }\n    ...> )","ref":"Mistral.html#ocr/2-structured-output-for-ocr"},{"type":"function","title":"Mistral.req/4","doc":"","ref":"Mistral.html#req/4"},{"type":"function","title":"Mistral.res/1","doc":"","ref":"Mistral.html#res/1"},{"type":"type","title":"Mistral.response/0","doc":"Client response","ref":"Mistral.html#t:response/0"},{"type":"function","title":"Mistral.upload_file/3","doc":"Uploads a file to the Mistral API.","ref":"Mistral.html#upload_file/3"},{"type":"function","title":"Options - Mistral.upload_file/3","doc":"* `:purpose` - Required. The purpose of the file. Currently supports 'ocr', 'fine-tune', and 'batch'.","ref":"Mistral.html#upload_file/3-options"},{"type":"function","title":"Examples - Mistral.upload_file/3","doc":"iex> Mistral.upload_file(client, \"path/to/file.pdf\", purpose: \"ocr\")\n    {:ok, %{\"id\" => \"file-abc123\", \"object\" => \"file\", ...}}","ref":"Mistral.html#upload_file/3-examples"},{"type":"exception","title":"Mistral.APIError","doc":"Exception raised when the Mistral API returns an error.","ref":"Mistral.APIError.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}